/****************************************************************************
** Meta object code from reading C++ file 'qabstractitemmodel_hook.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/qabstractitemmodel_hook.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qabstractitemmodel_hook.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16QModelIndex_hookE_t {};
} // unnamed namespace

template <> constexpr inline auto QModelIndex_hook::qt_create_metaobjectdata<qt_meta_tag_ZN16QModelIndex_hookE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QModelIndex_hook"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QModelIndex_hook, qt_meta_tag_ZN16QModelIndex_hookE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QModelIndex_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject_hook::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QModelIndex_hookE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QModelIndex_hookE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16QModelIndex_hookE_t>.metaTypes,
    nullptr
} };

void QModelIndex_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QModelIndex_hook *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *QModelIndex_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QModelIndex_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QModelIndex_hookE_t>.strings))
        return static_cast<void*>(this);
    return QObject_hook::qt_metacast(_clname);
}

int QModelIndex_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject_hook::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN26QPersistentModelIndex_hookE_t {};
} // unnamed namespace

template <> constexpr inline auto QPersistentModelIndex_hook::qt_create_metaobjectdata<qt_meta_tag_ZN26QPersistentModelIndex_hookE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QPersistentModelIndex_hook"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QPersistentModelIndex_hook, qt_meta_tag_ZN26QPersistentModelIndex_hookE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QPersistentModelIndex_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject_hook::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26QPersistentModelIndex_hookE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26QPersistentModelIndex_hookE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26QPersistentModelIndex_hookE_t>.metaTypes,
    nullptr
} };

void QPersistentModelIndex_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QPersistentModelIndex_hook *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *QPersistentModelIndex_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QPersistentModelIndex_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26QPersistentModelIndex_hookE_t>.strings))
        return static_cast<void*>(this);
    return QObject_hook::qt_metacast(_clname);
}

int QPersistentModelIndex_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject_hook::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN23QAbstractItemModel_hookE_t {};
} // unnamed namespace

template <> constexpr inline auto QAbstractItemModel_hook::qt_create_metaobjectdata<qt_meta_tag_ZN23QAbstractItemModel_hookE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QAbstractItemModel_hook",
        "dataChanged_hook",
        "",
        "QModelIndex",
        "topLeft",
        "bottomRight",
        "headerDataChanged_hook",
        "Qt::Orientation",
        "orientation",
        "first",
        "last",
        "layoutChanged_hook",
        "layoutAboutToBeChanged_hook",
        "rowsAboutToBeInserted_hook",
        "parent",
        "rowsInserted_hook",
        "rowsAboutToBeRemoved_hook",
        "rowsRemoved_hook",
        "columnsAboutToBeInserted_hook",
        "columnsInserted_hook",
        "columnsAboutToBeRemoved_hook",
        "columnsRemoved_hook",
        "modelAboutToBeReset_hook",
        "modelReset_hook",
        "rowsAboutToBeMoved_hook",
        "sourceParent",
        "sourceStart",
        "sourceEnd",
        "destinationParent",
        "destinationRow",
        "rowsMoved_hook",
        "start",
        "end",
        "destination",
        "row",
        "columnsAboutToBeMoved_hook",
        "destinationColumn",
        "columnsMoved_hook",
        "column"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'dataChanged_hook'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 5 },
        }}),
        // Slot 'headerDataChanged_hook'
        QtMocHelpers::SlotData<void(Qt::Orientation, int, int)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Slot 'layoutChanged_hook'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'layoutAboutToBeChanged_hook'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'rowsAboutToBeInserted_hook'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 14 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Slot 'rowsInserted_hook'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 14 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Slot 'rowsAboutToBeRemoved_hook'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 14 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Slot 'rowsRemoved_hook'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 14 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Slot 'columnsAboutToBeInserted_hook'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 14 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Slot 'columnsInserted_hook'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 14 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Slot 'columnsAboutToBeRemoved_hook'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 14 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Slot 'columnsRemoved_hook'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 14 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Slot 'modelAboutToBeReset_hook'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'modelReset_hook'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'rowsAboutToBeMoved_hook'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int, const QModelIndex &, int)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 25 }, { QMetaType::Int, 26 }, { QMetaType::Int, 27 }, { 0x80000000 | 3, 28 },
            { QMetaType::Int, 29 },
        }}),
        // Slot 'rowsMoved_hook'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int, const QModelIndex &, int)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 14 }, { QMetaType::Int, 31 }, { QMetaType::Int, 32 }, { 0x80000000 | 3, 33 },
            { QMetaType::Int, 34 },
        }}),
        // Slot 'columnsAboutToBeMoved_hook'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int, const QModelIndex &, int)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 25 }, { QMetaType::Int, 26 }, { QMetaType::Int, 27 }, { 0x80000000 | 3, 28 },
            { QMetaType::Int, 36 },
        }}),
        // Slot 'columnsMoved_hook'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int, const QModelIndex &, int)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 14 }, { QMetaType::Int, 31 }, { QMetaType::Int, 32 }, { 0x80000000 | 3, 33 },
            { QMetaType::Int, 38 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QAbstractItemModel_hook, qt_meta_tag_ZN23QAbstractItemModel_hookE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QAbstractItemModel_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject_hook::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QAbstractItemModel_hookE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QAbstractItemModel_hookE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23QAbstractItemModel_hookE_t>.metaTypes,
    nullptr
} };

void QAbstractItemModel_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QAbstractItemModel_hook *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dataChanged_hook((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 1: _t->headerDataChanged_hook((*reinterpret_cast<std::add_pointer_t<Qt::Orientation>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 2: _t->layoutChanged_hook(); break;
        case 3: _t->layoutAboutToBeChanged_hook(); break;
        case 4: _t->rowsAboutToBeInserted_hook((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 5: _t->rowsInserted_hook((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 6: _t->rowsAboutToBeRemoved_hook((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 7: _t->rowsRemoved_hook((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 8: _t->columnsAboutToBeInserted_hook((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 9: _t->columnsInserted_hook((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 10: _t->columnsAboutToBeRemoved_hook((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 11: _t->columnsRemoved_hook((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 12: _t->modelAboutToBeReset_hook(); break;
        case 13: _t->modelReset_hook(); break;
        case 14: _t->rowsAboutToBeMoved_hook((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 15: _t->rowsMoved_hook((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 16: _t->columnsAboutToBeMoved_hook((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 17: _t->columnsMoved_hook((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        default: ;
        }
    }
}

const QMetaObject *QAbstractItemModel_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QAbstractItemModel_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QAbstractItemModel_hookE_t>.strings))
        return static_cast<void*>(this);
    return QObject_hook::qt_metacast(_clname);
}

int QAbstractItemModel_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject_hook::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN24QAbstractTableModel_hookE_t {};
} // unnamed namespace

template <> constexpr inline auto QAbstractTableModel_hook::qt_create_metaobjectdata<qt_meta_tag_ZN24QAbstractTableModel_hookE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QAbstractTableModel_hook"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QAbstractTableModel_hook, qt_meta_tag_ZN24QAbstractTableModel_hookE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QAbstractTableModel_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel_hook::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QAbstractTableModel_hookE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QAbstractTableModel_hookE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24QAbstractTableModel_hookE_t>.metaTypes,
    nullptr
} };

void QAbstractTableModel_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QAbstractTableModel_hook *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *QAbstractTableModel_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QAbstractTableModel_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QAbstractTableModel_hookE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel_hook::qt_metacast(_clname);
}

int QAbstractTableModel_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel_hook::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN23QAbstractListModel_hookE_t {};
} // unnamed namespace

template <> constexpr inline auto QAbstractListModel_hook::qt_create_metaobjectdata<qt_meta_tag_ZN23QAbstractListModel_hookE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QAbstractListModel_hook"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QAbstractListModel_hook, qt_meta_tag_ZN23QAbstractListModel_hookE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QAbstractListModel_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel_hook::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QAbstractListModel_hookE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QAbstractListModel_hookE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23QAbstractListModel_hookE_t>.metaTypes,
    nullptr
} };

void QAbstractListModel_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QAbstractListModel_hook *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *QAbstractListModel_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QAbstractListModel_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QAbstractListModel_hookE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel_hook::qt_metacast(_clname);
}

int QAbstractListModel_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel_hook::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
