/****************************************************************************
** Meta object code from reading C++ file 'qtoolbar_hook.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/qtoolbar_hook.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qtoolbar_hook.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13QToolBar_hookE_t {};
} // unnamed namespace

template <> constexpr inline auto QToolBar_hook::qt_create_metaobjectdata<qt_meta_tag_ZN13QToolBar_hookE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QToolBar_hook",
        "actionTriggered_hook",
        "",
        "QAction*",
        "action",
        "movableChanged_hook",
        "movable",
        "allowedAreasChanged_hook",
        "Qt::ToolBarAreas",
        "allowedAreas",
        "orientationChanged_hook",
        "Qt::Orientation",
        "orientation",
        "iconSizeChanged_hook",
        "QSize",
        "iconSize",
        "toolButtonStyleChanged_hook",
        "Qt::ToolButtonStyle",
        "toolButtonStyle",
        "topLevelChanged_hook",
        "topLevel",
        "visibilityChanged_hook",
        "visible"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'actionTriggered_hook'
        QtMocHelpers::SlotData<void(QAction *)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'movableChanged_hook'
        QtMocHelpers::SlotData<void(bool)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'allowedAreasChanged_hook'
        QtMocHelpers::SlotData<void(Qt::ToolBarAreas)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'orientationChanged_hook'
        QtMocHelpers::SlotData<void(Qt::Orientation)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'iconSizeChanged_hook'
        QtMocHelpers::SlotData<void(const QSize &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'toolButtonStyleChanged_hook'
        QtMocHelpers::SlotData<void(Qt::ToolButtonStyle)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'topLevelChanged_hook'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'visibilityChanged_hook'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QToolBar_hook, qt_meta_tag_ZN13QToolBar_hookE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QToolBar_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget_hook::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QToolBar_hookE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QToolBar_hookE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13QToolBar_hookE_t>.metaTypes,
    nullptr
} };

void QToolBar_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QToolBar_hook *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->actionTriggered_hook((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 1: _t->movableChanged_hook((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->allowedAreasChanged_hook((*reinterpret_cast<std::add_pointer_t<Qt::ToolBarAreas>>(_a[1]))); break;
        case 3: _t->orientationChanged_hook((*reinterpret_cast<std::add_pointer_t<Qt::Orientation>>(_a[1]))); break;
        case 4: _t->iconSizeChanged_hook((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 5: _t->toolButtonStyleChanged_hook((*reinterpret_cast<std::add_pointer_t<Qt::ToolButtonStyle>>(_a[1]))); break;
        case 6: _t->topLevelChanged_hook((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->visibilityChanged_hook((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *QToolBar_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QToolBar_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QToolBar_hookE_t>.strings))
        return static_cast<void*>(this);
    return QWidget_hook::qt_metacast(_clname);
}

int QToolBar_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget_hook::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
