/****************************************************************************
** Meta object code from reading C++ file 'qtablewidget_hook.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/qtablewidget_hook.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qtablewidget_hook.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN31QTableWidgetSelectionRange_hookE_t {};
} // unnamed namespace

template <> constexpr inline auto QTableWidgetSelectionRange_hook::qt_create_metaobjectdata<qt_meta_tag_ZN31QTableWidgetSelectionRange_hookE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QTableWidgetSelectionRange_hook"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QTableWidgetSelectionRange_hook, qt_meta_tag_ZN31QTableWidgetSelectionRange_hookE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QTableWidgetSelectionRange_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject_hook::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31QTableWidgetSelectionRange_hookE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31QTableWidgetSelectionRange_hookE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN31QTableWidgetSelectionRange_hookE_t>.metaTypes,
    nullptr
} };

void QTableWidgetSelectionRange_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QTableWidgetSelectionRange_hook *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *QTableWidgetSelectionRange_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QTableWidgetSelectionRange_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31QTableWidgetSelectionRange_hookE_t>.strings))
        return static_cast<void*>(this);
    return QObject_hook::qt_metacast(_clname);
}

int QTableWidgetSelectionRange_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject_hook::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN21QTableWidgetItem_hookE_t {};
} // unnamed namespace

template <> constexpr inline auto QTableWidgetItem_hook::qt_create_metaobjectdata<qt_meta_tag_ZN21QTableWidgetItem_hookE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QTableWidgetItem_hook"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QTableWidgetItem_hook, qt_meta_tag_ZN21QTableWidgetItem_hookE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QTableWidgetItem_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject_hook::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QTableWidgetItem_hookE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QTableWidgetItem_hookE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21QTableWidgetItem_hookE_t>.metaTypes,
    nullptr
} };

void QTableWidgetItem_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QTableWidgetItem_hook *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *QTableWidgetItem_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QTableWidgetItem_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QTableWidgetItem_hookE_t>.strings))
        return static_cast<void*>(this);
    return QObject_hook::qt_metacast(_clname);
}

int QTableWidgetItem_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject_hook::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN17QTableWidget_hookE_t {};
} // unnamed namespace

template <> constexpr inline auto QTableWidget_hook::qt_create_metaobjectdata<qt_meta_tag_ZN17QTableWidget_hookE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QTableWidget_hook",
        "itemPressed_hook",
        "",
        "QTableWidgetItem*",
        "item",
        "itemClicked_hook",
        "itemDoubleClicked_hook",
        "itemActivated_hook",
        "itemEntered_hook",
        "itemChanged_hook",
        "currentItemChanged_hook",
        "current",
        "previous",
        "itemSelectionChanged_hook",
        "cellPressed_hook",
        "row",
        "column",
        "cellClicked_hook",
        "cellDoubleClicked_hook",
        "cellActivated_hook",
        "cellEntered_hook",
        "cellChanged_hook",
        "currentCellChanged_hook",
        "currentRow",
        "currentColumn",
        "previousRow",
        "previousColumn"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'itemPressed_hook'
        QtMocHelpers::SlotData<void(QTableWidgetItem *)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'itemClicked_hook'
        QtMocHelpers::SlotData<void(QTableWidgetItem *)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'itemDoubleClicked_hook'
        QtMocHelpers::SlotData<void(QTableWidgetItem *)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'itemActivated_hook'
        QtMocHelpers::SlotData<void(QTableWidgetItem *)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'itemEntered_hook'
        QtMocHelpers::SlotData<void(QTableWidgetItem *)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'itemChanged_hook'
        QtMocHelpers::SlotData<void(QTableWidgetItem *)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'currentItemChanged_hook'
        QtMocHelpers::SlotData<void(QTableWidgetItem *, QTableWidgetItem *)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 11 }, { 0x80000000 | 3, 12 },
        }}),
        // Slot 'itemSelectionChanged_hook'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cellPressed_hook'
        QtMocHelpers::SlotData<void(int, int)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'cellClicked_hook'
        QtMocHelpers::SlotData<void(int, int)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'cellDoubleClicked_hook'
        QtMocHelpers::SlotData<void(int, int)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'cellActivated_hook'
        QtMocHelpers::SlotData<void(int, int)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'cellEntered_hook'
        QtMocHelpers::SlotData<void(int, int)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'cellChanged_hook'
        QtMocHelpers::SlotData<void(int, int)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'currentCellChanged_hook'
        QtMocHelpers::SlotData<void(int, int, int, int)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 23 }, { QMetaType::Int, 24 }, { QMetaType::Int, 25 }, { QMetaType::Int, 26 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QTableWidget_hook, qt_meta_tag_ZN17QTableWidget_hookE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QTableWidget_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QTableView_hook::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QTableWidget_hookE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QTableWidget_hookE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QTableWidget_hookE_t>.metaTypes,
    nullptr
} };

void QTableWidget_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QTableWidget_hook *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->itemPressed_hook((*reinterpret_cast<std::add_pointer_t<QTableWidgetItem*>>(_a[1]))); break;
        case 1: _t->itemClicked_hook((*reinterpret_cast<std::add_pointer_t<QTableWidgetItem*>>(_a[1]))); break;
        case 2: _t->itemDoubleClicked_hook((*reinterpret_cast<std::add_pointer_t<QTableWidgetItem*>>(_a[1]))); break;
        case 3: _t->itemActivated_hook((*reinterpret_cast<std::add_pointer_t<QTableWidgetItem*>>(_a[1]))); break;
        case 4: _t->itemEntered_hook((*reinterpret_cast<std::add_pointer_t<QTableWidgetItem*>>(_a[1]))); break;
        case 5: _t->itemChanged_hook((*reinterpret_cast<std::add_pointer_t<QTableWidgetItem*>>(_a[1]))); break;
        case 6: _t->currentItemChanged_hook((*reinterpret_cast<std::add_pointer_t<QTableWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QTableWidgetItem*>>(_a[2]))); break;
        case 7: _t->itemSelectionChanged_hook(); break;
        case 8: _t->cellPressed_hook((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 9: _t->cellClicked_hook((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 10: _t->cellDoubleClicked_hook((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 11: _t->cellActivated_hook((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 12: _t->cellEntered_hook((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 13: _t->cellChanged_hook((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 14: _t->currentCellChanged_hook((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        default: ;
        }
    }
}

const QMetaObject *QTableWidget_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QTableWidget_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QTableWidget_hookE_t>.strings))
        return static_cast<void*>(this);
    return QTableView_hook::qt_metacast(_clname);
}

int QTableWidget_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTableView_hook::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
