/****************************************************************************
** Meta object code from reading C++ file 'qwindow_hook.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/qwindow_hook.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qwindow_hook.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12QWindow_hookE_t {};
} // unnamed namespace

template <> constexpr inline auto QWindow_hook::qt_create_metaobjectdata<qt_meta_tag_ZN12QWindow_hookE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWindow_hook",
        "screenChanged_hook",
        "",
        "QScreen*",
        "screen",
        "modalityChanged_hook",
        "Qt::WindowModality",
        "modality",
        "windowStateChanged_hook",
        "Qt::WindowState",
        "windowState",
        "windowTitleChanged_hook",
        "title",
        "xChanged_hook",
        "arg",
        "yChanged_hook",
        "widthChanged_hook",
        "heightChanged_hook",
        "minimumWidthChanged_hook",
        "minimumHeightChanged_hook",
        "maximumWidthChanged_hook",
        "maximumHeightChanged_hook",
        "visibleChanged_hook",
        "visibilityChanged_hook",
        "QWindow::Visibility",
        "visibility",
        "activeChanged_hook",
        "contentOrientationChanged_hook",
        "Qt::ScreenOrientation",
        "orientation",
        "focusObjectChanged_hook",
        "object",
        "opacityChanged_hook",
        "opacity"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'screenChanged_hook'
        QtMocHelpers::SlotData<void(QScreen *)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'modalityChanged_hook'
        QtMocHelpers::SlotData<void(Qt::WindowModality)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'windowStateChanged_hook'
        QtMocHelpers::SlotData<void(Qt::WindowState)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'windowTitleChanged_hook'
        QtMocHelpers::SlotData<void(const QString &)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'xChanged_hook'
        QtMocHelpers::SlotData<void(int)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'yChanged_hook'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'widthChanged_hook'
        QtMocHelpers::SlotData<void(int)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'heightChanged_hook'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'minimumWidthChanged_hook'
        QtMocHelpers::SlotData<void(int)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'minimumHeightChanged_hook'
        QtMocHelpers::SlotData<void(int)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'maximumWidthChanged_hook'
        QtMocHelpers::SlotData<void(int)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'maximumHeightChanged_hook'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'visibleChanged_hook'
        QtMocHelpers::SlotData<void(bool)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'visibilityChanged_hook'
        QtMocHelpers::SlotData<void(QWindow::Visibility)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'activeChanged_hook'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'contentOrientationChanged_hook'
        QtMocHelpers::SlotData<void(Qt::ScreenOrientation)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'focusObjectChanged_hook'
        QtMocHelpers::SlotData<void(QObject *)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 31 },
        }}),
        // Slot 'opacityChanged_hook'
        QtMocHelpers::SlotData<void(qreal)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 33 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QWindow_hook, qt_meta_tag_ZN12QWindow_hookE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QWindow_hook::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject_hook::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12QWindow_hookE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12QWindow_hookE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12QWindow_hookE_t>.metaTypes,
    nullptr
} };

void QWindow_hook::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWindow_hook *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->screenChanged_hook((*reinterpret_cast<std::add_pointer_t<QScreen*>>(_a[1]))); break;
        case 1: _t->modalityChanged_hook((*reinterpret_cast<std::add_pointer_t<Qt::WindowModality>>(_a[1]))); break;
        case 2: _t->windowStateChanged_hook((*reinterpret_cast<std::add_pointer_t<Qt::WindowState>>(_a[1]))); break;
        case 3: _t->windowTitleChanged_hook((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->xChanged_hook((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->yChanged_hook((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->widthChanged_hook((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->heightChanged_hook((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->minimumWidthChanged_hook((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->minimumHeightChanged_hook((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->maximumWidthChanged_hook((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->maximumHeightChanged_hook((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->visibleChanged_hook((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->visibilityChanged_hook((*reinterpret_cast<std::add_pointer_t<QWindow::Visibility>>(_a[1]))); break;
        case 14: _t->activeChanged_hook(); break;
        case 15: _t->contentOrientationChanged_hook((*reinterpret_cast<std::add_pointer_t<Qt::ScreenOrientation>>(_a[1]))); break;
        case 16: _t->focusObjectChanged_hook((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 17: _t->opacityChanged_hook((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QScreen* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *QWindow_hook::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWindow_hook::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12QWindow_hookE_t>.strings))
        return static_cast<void*>(this);
    return QObject_hook::qt_metacast(_clname);
}

int QWindow_hook::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject_hook::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}
QT_WARNING_POP
